@@ -14,7 +14,7 @@ from subprocess import PIPE, Popen
 from tempfile import NamedTemporaryFile
 from threading import Lock
 from time import sleep
-from typing import List, Optional, Union
+from typing import List, Optional, Tuple, Union
 
 from loguru import logger
 
@@ -177,16 +177,13 @@ class Transcoder:
         op = op or self.op()
         assert force_no_transcode, 'Transcoding not supported yet for chop'
         assert (
-            pos_start_s is None
-        ), 'Custom start position not supported yet for chop'
-        assert (
-            pos_end_s is not None
-        ), 'Undefined end position not supported yet for chop'
+            pos_start_s is None or pos_end_s is not None
+        ), 'Must specify either start or end position to chop to'
         self.ffmpeg(
             *['-i', in_file],
             *['-c', 'copy'],
-            *['-ss', '0'],
-            *['-t', str(pos_end_s)],
+            *['-ss', str(pos_start_s)] * (pos_start_s is not None),
+            *['-to', str(pos_end_s)] * (pos_end_s is not None),
             out_file,
             duration_s=self.info(in_file).duration_s if on_progress else None,
             on_progress=on_progress,
@@ -549,6 +546,30 @@ class Transcoder:
             )
         return out_file
 
+    def edit(
+        self,
+        in_file: str,
+        cuts: List[Tuple[float, float]],
+        output_file: str,
+        on_progress: ProgressHandler = None,
+        op: FfmpegOperation = None,
+    ) -> str:
+        op = op or self.op()
+        filter_str = '+'.join(
+            f'between(t,{start},{end})' for start, end in cuts
+        )
+
+        self.ffmpeg(
+            *('-i', in_file),
+            *('-vf', f"select='{filter_str}',setpts=N/FRAME_RATE/TB"),
+            *('-af', f"aselect='{filter_str}',asetpts=N/SR/TB"),
+            output_file,
+            duration_s=self.info(in_file).duration_s if on_progress else None,
+            on_progress=on_progress,
+            op=op,
+        )
+        return output_file
+
     def split(
         self,
         in_file: str,
